## 0.0.6

This new version includes an example notebook for QueryBot and a version bump.

### New Features

- Added an example notebook for QueryBot (fa7182) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
